@@ -25,6 +25,7 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                  next_action: Union[str, 'ConfiguredAction'] = None,
                  condition: Union[Tuple[object, str], Callable] = None,
                  aliases: List[str] = None,
+                 use_unique_action: bool = False,
                  **kwargs,
                  ):
         """
@@ -42,12 +43,15 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
             at runtime for a bool.
         :param kwargs: keyword arguments for the action
         :param aliases: list of aliases which refer to the configured action instance
+        :param use_unique_action: whether to register action as a unique action (usually in cases where actions have
+            stateful instance dependencies and there may be more than one action of the same name registered)
         """
         # todo ability to retrieve the executions of a given configured action
         InstanceRegistry.__init__(self)
         self._action: Action = None
         self._config_name: str = None
         self._next_action = None
+        self._use_unique_action = use_unique_action
         # list of aliases for the configuration
         if aliases is None:
             aliases = []  # prevent mutation
@@ -102,7 +106,10 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
     @action.setter
     def action(self, value: Union[Callable, Action, str]):
         if value is not None:
-            self._action = Action.register_action(value)
+            self._action = Action.register_action(
+                value,
+                self._uuid if self._use_unique_action is True else None
+            )
 
     @property
     def name(self) -> str:
@@ -285,10 +292,12 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                 # try to retrieve configuration by name
                 return ConfiguredAction.class_instance_by_id(configuration)
             except NameError:
+                try:
+                    action = Action.register_action(configuration)
+                except TypeError:
+                    raise ValueError(f'the action "{configuration}" is not registered')
                 # attempt to create a configuration from a registered action
-                return ConfiguredAction(
-                    Action.register_action(configuration)
-                )
+                return ConfiguredAction(action)
         # if an action, create
         elif isinstance(configuration, Action):
             # if an action was provided, create configuration
@@ -371,23 +380,31 @@ class ConfiguredActionList(ActionList):
 class ConfigurableInstance:
     methods_to_register: List[str] = []
 
-    def __init__(self):
+    def __init__(self, instance_specific_actions: bool = False):
         """
         A base class which will register a class instance's methods as ConfiguredActions. The method names in the
         methods_to_register list will be registered as configured actions upon instantiation.
 
         Subclasses should overwrite the list of methods to register and call init.
+
+        :param instance_specific_actions: whether the configured instance should use instance-specific actions (e.g. the
+            action depends on the state of the instance)
         """
+        self.instance_specific_actions = instance_specific_actions
         self._register_instance_actions()
 
     def _register_instance_actions(self):
         """registers instance actions as ConfiguredActions"""
         for method_name in self.methods_to_register:
             if isinstance(getattr(self, method_name), ConfiguredAction) is False:
+                ca = ConfiguredAction(
+                    getattr(self, method_name),
+                    use_unique_action=self.instance_specific_actions,
+                )
                 setattr(
                     self,
                     method_name,
-                    ConfiguredAction(getattr(self, method_name))
+                    ca,
                 )
 
     def execute_action(self, action: str, *args, **kwargs) -> 'TrackedAction':
