@@ -119,6 +119,11 @@ class SamplingScheduler(InstanceRegistry):
         """list of time points for the sequence"""
         return self._time_points
 
+    @property
+    def total_time_points(self) -> int:
+        """total number of time points associated with the scheduler instance"""
+        return len(self.time_points)
+
     @property
     def triggered_time_points(self) -> int:
         """number of triggered time points"""
@@ -129,6 +134,16 @@ class SamplingScheduler(InstanceRegistry):
         """number of time points remaining to be sampled"""
         return len([tp for tp in self.time_points if tp.triggered is False])
 
+    @property
+    def completed_time_points(self) -> int:
+        """number of time points which have been completed"""
+        return len([tp for tp in self.time_points if tp.status_code == 3 or tp.status_code < 0])
+
+    @property
+    def uncompleted_time_points(self) -> int:
+        """number of time points which have not been completed"""
+        return len([tp for tp in self.time_points if 0 < tp.status_code < 3])
+
     @property
     def next_time_point(self) -> Union[ActionTimePoint, None]:
         """The next time point for triggering"""
@@ -510,9 +525,12 @@ class SamplingScheduler(InstanceRegistry):
             'instance_actions': [action.name for action in self.sequence.action_sequence],
             'started': self.started,
             'created': self.created,
-            'num_time_points': len(self.time_points),
+            'num_time_points': self.total_time_points,  # todo deprecate
+            'total_time_points': self.total_time_points,
             'sampled_time_points': self.triggered_time_points,
             'remaining_time_points': self.remaining_time_points,
+            'completed_time_points': self.completed_time_points,
+            'uncompleted_time_points': self.uncompleted_time_points,
         }
         if self.next_time_point is not None:
             out['next_time_point'] = self.next_time_point.time_delta
@@ -617,7 +635,7 @@ class ExecuteOnTimePoints(ConfiguredAction):
         """regex pattern for matching timepoint names"""
         value_pattern = "|".join([str(val) for val in self.timepoints])
         return re.compile(
-            f'Time Point #({value_pattern})'
+            f'Time Point #({value_pattern})$'
         )
 
     def evaluate_condition(self) -> bool:
