@@ -184,6 +184,12 @@ class TestActions(unittest.TestCase):
             ValueError,
             action
         )
+        self.assertRaises(
+            TypeError,
+            Action,
+            ('asdf123'),
+            'check that non-callables are correctly rejected as actions'
+        )
 
 
 def return_str() -> str:
@@ -630,7 +636,7 @@ class TestOperators(unittest.TestCase):
                                         **{'one': 'first one'}
                                         )
 
-        eval_action = EvalAction(self.return_bool)
+        eval_action = EvalAction.register_action(self.return_bool)
         conf_true = ConfiguredAction(eval_action, next_action=config_log_1, **{'bool': True})
         conf_false = ConfiguredAction(eval_action, next_action=config_log_2, **{'bool': False})
 
@@ -664,6 +670,9 @@ class RegMethodsInstance(ConfigurableInstance):
         'inst_action_two',
     ]
 
+    def __init__(self):
+        ConfigurableInstance.__init__(self, instance_specific_actions=True)
+
     def inst_action_one(self):
         return 'banana'
 
@@ -675,6 +684,7 @@ class TestConfigurableInstance(unittest.TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         cls.test_inst = RegMethodsInstance()
+        cls.test_inst2 = RegMethodsInstance()
 
     def test_registered(self):
         """tests that methods are registered"""
@@ -701,3 +711,14 @@ class TestConfigurableInstance(unittest.TestCase):
         execute_and_test('inst_action_one', 'banana')
         execute_and_test('inst_action_two', 'split')
 
+    def test_method_associations(self):
+        """tests that registered methods of a class are not methods of the other"""
+        self.assertFalse(
+            self.test_inst.inst_action_one is self.test_inst2.inst_action_one,
+            "ensure configured actions are not duplicates"
+        )
+        self.assertFalse(
+            self.test_inst.inst_action_one.action.action
+            is self.test_inst2.inst_action_one.action.action,
+            "ensure actions point to correct instance"
+        )
